#!/bin/sh
export PATH='/wrkdirs/usr/ports/devel/hs-lens/work/.bin:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: lens
version: 4.16.1
id: lens-4.16.1-503SWXiMLbFIiNElNOw7Cc
key: lens-4.16.1-503SWXiMLbFIiNElNOw7Cc
license: BSD-2-Clause
copyright: Copyright (C) 2012-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/lens/
synopsis: Lenses, Folds and Traversals
description:
    This package comes \"Batteries Included\" with many useful lenses for the types
    commonly used from the Haskell Platform, and with tools for automatically
    generating lenses and isomorphisms for user-supplied data types.
    .
    The combinators in @Control.Lens@ provide a highly generic toolbox for composing
    families of getters, folds, isomorphisms, traversals, setters and lenses and their
    indexed variants.
    .
    An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.
    .
    An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.
    .
    A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.
    .
    Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.
    .
    More information on the care and feeding of lenses, including a brief tutorial and motivation
    for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.
    .
    A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.
    .
    /Lenses, Folds and Traversals/
    .
    With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:
    .
    .
    <<http://i.imgur.com/ALlbPRa.png>>
    .
    <Hierarchy.png (Local Copy)>
    .
    You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
    use any element of the hierarchy as any type it linked to above it.
    .
    The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
    .
    For instance:
    .
    * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
    .
    * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
    .
    /Minimizing Dependencies/
    .
    If you want to provide lenses and traversals for your own types in your own libraries, then you
    can do so without incurring a dependency on this (or any other) lens package at all.
    .
    /e.g./ for a data type:
    .
    > data Foo a = Foo Int Int a
    .
    You can define lenses such as
    .
    > -- bar :: Lens'\'' (Foo a) Int
    > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
    > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
    .
    > -- quux :: Lens (Foo a) (Foo b) a b
    > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
    > quux f (Foo a b c) = fmap (Foo a b) (f c)
    .
    without the need to use any type that isn'\''t already defined in the @Prelude@.
    .
    And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
    .
    > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
    > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
    > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
    .
    What is provided in this library is a number of stock lenses and traversals for
    common haskell types, a wide array of combinators for working them, and more
    exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses, Generics
abi: 4772a858da0f0715ad6856ec1478c51c
exposed: True
exposed-modules:
    Control.Exception.Lens Control.Lens Control.Lens.At
    Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
    Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
    Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
    Control.Lens.Internal Control.Lens.Internal.Bazaar
    Control.Lens.Internal.ByteString Control.Lens.Internal.CTypes
    Control.Lens.Internal.Coerce Control.Lens.Internal.Context
    Control.Lens.Internal.Deque Control.Lens.Internal.Exception
    Control.Lens.Internal.FieldTH Control.Lens.Internal.Fold
    Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
    Control.Lens.Internal.Instances Control.Lens.Internal.Iso
    Control.Lens.Internal.Level Control.Lens.Internal.List
    Control.Lens.Internal.Magma Control.Lens.Internal.Prism
    Control.Lens.Internal.PrismTH Control.Lens.Internal.Review
    Control.Lens.Internal.Setter Control.Lens.Internal.TH
    Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
    Control.Lens.Level Control.Lens.Operators Control.Lens.Plated
    Control.Lens.Prism Control.Lens.Reified Control.Lens.Review
    Control.Lens.Setter Control.Lens.TH Control.Lens.Traversal
    Control.Lens.Tuple Control.Lens.Type Control.Lens.Unsound
    Control.Lens.Wrapped Control.Lens.Zoom Control.Monad.Error.Lens
    Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
    Data.Bits.Lens Data.ByteString.Lazy.Lens Data.ByteString.Lens
    Data.ByteString.Strict.Lens Data.Complex.Lens Data.Data.Lens
    Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
    Data.Map.Lens Data.Sequence.Lens Data.Set.Lens Data.Text.Lazy.Lens
    Data.Text.Lens Data.Text.Strict.Lens Data.Tree.Lens
    Data.Typeable.Lens Data.Vector.Generic.Lens Data.Vector.Lens
    GHC.Generics.Lens Language.Haskell.TH.Lens Numeric.Lens
    Numeric.Natural.Lens System.Exit.Lens System.FilePath.Lens
    System.IO.Error.Lens
hidden-modules: Paths_lens
import-dirs: /usr/local/lib/cabal/ghc-8.4.3/lens-4.16.1
library-dirs: /usr/local/lib/cabal/ghc-8.4.3/lens-4.16.1
              /usr/local/lib
dynamic-library-dirs: /usr/local/lib/cabal/ghc-8.4.3/x86_64-freebsd-ghc-8.4.3
                      /usr/local/lib
data-dir: /usr/local/share/cabal/ghc-8.4.3/lens-4.16.1
hs-libraries: HSlens-4.16.1-503SWXiMLbFIiNElNOw7Cc
include-dirs: /usr/local/include
depends:
    array-0.5.2.0 base-4.11.1.0 base-orphans-0.6-8GW2IQi6D0NBW7aJTanC0x
    bifunctors-5.5.2-4wnnrTcojYhEpt7HnIXUTi bytestring-0.10.8.2
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    comonad-5.0.3-IWi8zXCKg9C6wxhCeL7xKT
    contravariant-1.4-J9NaZypxUdK9npGfTMhcTU containers-0.5.11.0
    distributive-0.5.3-AII1TTUhR9FLI4Hfrs3DkN filepath-1.4.2
    free-5.0.1-IQFBI7t1LT161lTWoUc3D8 ghc-prim-0.5.2.0
    hashable-1.2.7.0-32YJc3oTU0i5Q1RvbeCb0C
    kan-extensions-5.1-fdS4XgD8tn5y260inet47
    exceptions-0.10.0-DItW7BM25Zz5r6SzsXOWGb mtl-2.2.2
    parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE
    profunctors-5.2.2-HDBDBz2UJ9gCu4AjcHBV98
    reflection-2.1.3-63T1JznjTlmGCR7c45ZHcS
    semigroupoids-5.2.2-L2PIw9OIOUrDc2gJFOm2CX
    semigroups-0.18.4-8TzSEFpYt1WDcfY361NEhv
    tagged-0.8.5-Dknw41JMyUHEcMsHdNXv1c template-haskell-2.13.0.0
    th-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4 text-1.2.3.0
    transformers-0.5.5.0
    transformers-compat-0.5.1.4-BG7wgRauI8h5onKXiYZE4l
    unordered-containers-0.2.9.0-2rgz5q1wIMZCVTOPtEhIaQ
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb
    void-0.7.2-AeUlTizrscF7IT5YtjodSF
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=d353a93de60ba3601dfa5501e270cfc5
             base-orphans-0.6-8GW2IQi6D0NBW7aJTanC0x=60c95f48b8ac175d3c1c5540a8c37eba
             bifunctors-5.5.2-4wnnrTcojYhEpt7HnIXUTi=4f4cfe25dd52e80f254b5cebae857c91
             bytestring-0.10.8.2=7e6ff0f3c2255fe1b20bd14002d26042
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             comonad-5.0.3-IWi8zXCKg9C6wxhCeL7xKT=b3f40193633d22963827e6233c0c76e8
             contravariant-1.4-J9NaZypxUdK9npGfTMhcTU=44928603fb3cc9cbd1cea34799688dc7
             containers-0.5.11.0=d384b381e11d19983236150d9c2d8d67
             distributive-0.5.3-AII1TTUhR9FLI4Hfrs3DkN=9659cfed9ef5503634a5c8f4c9a102af
             filepath-1.4.2=199aef3b23f4884447a6092b74bc0baf
             free-5.0.1-IQFBI7t1LT161lTWoUc3D8=64784154d6ef7cd76e2c696a0dde06bd
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-32YJc3oTU0i5Q1RvbeCb0C=b0ce70866a180a33c120b05b203e8b31
             kan-extensions-5.1-fdS4XgD8tn5y260inet47=e62c257690f0dde38ca4dd5646975289
             exceptions-0.10.0-DItW7BM25Zz5r6SzsXOWGb=3b7954b96c2c87bf5286292d76d1f9de
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=0c2ede1954688e9998871af19fc030ac
             profunctors-5.2.2-HDBDBz2UJ9gCu4AjcHBV98=a372852b32db7f6910ecc7a59405a0eb
             reflection-2.1.3-63T1JznjTlmGCR7c45ZHcS=85a970a54ecdf19710f7da1e9b7d2d89
             semigroupoids-5.2.2-L2PIw9OIOUrDc2gJFOm2CX=031bd43d3cc914b9f51ee4d572be2918
             semigroups-0.18.4-8TzSEFpYt1WDcfY361NEhv=2dc880003fe9a2987c0e7231220d530d
             tagged-0.8.5-Dknw41JMyUHEcMsHdNXv1c=fb8a9f4f048ca1b78e957c45faff3822
             template-haskell-2.13.0.0=105dfce6dad622b49a6837079f722cd7
             th-abstraction-0.2.6.0-8bhBYrrqrAJFCd9hjMrFb4=4167056d0f28e936447d3d0f563e79af
             text-1.2.3.0=9ad7bbe7c5dcb4150d56b6f4034f18b1
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.5.1.4-BG7wgRauI8h5onKXiYZE4l=582d2f2e0d7d45276174992c9bc0b19c
             unordered-containers-0.2.9.0-2rgz5q1wIMZCVTOPtEhIaQ=7ffeb981cd9aa718324998ca683a588c
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=910e569d11f2c11c0ad4a6f45abd85db
             void-0.7.2-AeUlTizrscF7IT5YtjodSF=090d94639917fd1ba9268f065afd7b7c
haddock-interfaces: /usr/local/share/doc/cabal/ghc-8.4.3/lens-4.16.1/html/lens.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-8.4.3/lens-4.16.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

